.. image:: https://github.com/bast/cicero/workflows/Test/badge.svg
   :target: https://github.com/bast/cicero/actions
.. image:: https://img.shields.io/badge/license-%20AGPLv3-blue.svg
   :target: LICENSE
.. image:: https://img.shields.io/badge/vue-2.5.16-green.svg
   :target: https://vuejs.org
.. image:: https://badge.fury.io/py/cicero.svg
   :target: https://badge.fury.io/py/cicero


Cicero
======

Serving presentation slides written in Markdown: https://cicero.xyz

In the background uses:

- `remark <https://github.com/gnab/remark>`__, a
  simple, in-browser, markdown-driven slideshow tool created by `Ole
  Petter Bang <https://github.com/gnab>`__.
- `reveal.js <https://revealjs.com>`__, created by
  `Hakim El Hattab <https://hakim.se>`__ and contributors.


Documentation
-------------

- https://cicero.readthedocs.io
- `Changelog <CHANGES.rst>`__


Authors
-------

- `Radovan Bast <http://bast.fr>`__ (idea, pilot implementation, and
  plumbing)
- `Ole Martin Bjørndalen <https://github.com/olemb>`__ (local preview
  and Blueprint solution)
- `Roberto Di Remigio <http://totaltrash.xyz>`__ (MathJax support,
  local templating idea, slide splits)


Contributions
-------------

- `Jyry Suvilehto <https://github.com/jyrsa>`__ (setup.py script)
- `Martti Louhivuori <https://github.com/mlouhivu>`__ (first version of the
  JavaScript and configuration customization)
